@@ -15,17 +15,13 @@ import json
 from io import open
 from os import listdir, pathsep
 from os.path import join, isfile, isdir, dirname
-import sys
 import contextlib
 import platform
 import itertools
 import subprocess
 import distutils.errors
-from packaging.version import LegacyVersion
 from more_itertools import unique_everseen
 
-from .monkey import get_unpatched
-
 if platform.system() == 'Windows':
     import winreg
     from os import environ
@@ -217,19 +213,6 @@ def msvc14_get_vc_env(plat_spec):
         raise
 
 
-def msvc14_gen_lib_options(*args, **kwargs):
-    """
-    Patched "distutils._msvccompiler.gen_lib_options" for fix
-    compatibility between "numpy.distutils" and "distutils._msvccompiler"
-    (for Numpy < 1.11.2)
-    """
-    if "numpy.distutils" in sys.modules:
-        import numpy as np
-        if LegacyVersion(np.__version__) < LegacyVersion('1.11.2'):
-            return np.distutils.ccompiler.gen_lib_options(*args, **kwargs)
-    return get_unpatched(msvc14_gen_lib_options)(*args, **kwargs)
-
-
 def _augment_exception(exc, version, arch=''):
     """
     Add details to the exception message to help guide the user
